@@ -22,6 +22,10 @@ doconce_envirs = ['c', 't',                # verbatim and tex blocks
             'quiz', 'u-',
             ]
 
+# Postfixes allowed on code blocks e.g. `pycod-e` and regex to catch them
+postfix_code_block = ['hid', '-h', '-e', '-t', 'out']
+postfix_regex = '(?:' + '|'.join(postfix_code_block) + '|)'
+
 main_content_char = '-'
 
 # Python colors and styling for printing
@@ -46,6 +50,10 @@ inline_tag_end = r"""(?P<end>($|[.,?!;:)<}!'\s~\[<&;-]))"""
 # Admonitions
 admons = 'notice', 'summary', 'warning', 'question', 'block'
 
+# Identifiers in the text used to identify code and math blocks
+_CODE_BLOCK = '<<<!!CODE_BLOCK'
+_MATH_BLOCK = '<<<!!MATH_BLOCK'
+
 # Support for non-English languages (not really implemented yet)
 locale_dict = dict(
     language='English',  # language to be used
