@@ -2,17 +2,17 @@ from __future__ import absolute_import
 from builtins import str
 from builtins import range
 import re, sys, shutil, os
-from .common import default_movie, plain_exercise, table_analysis, \
-     insert_code_and_tex, indent_lines, bibliography, fix_ref_section_chapter, \
-    cite_with_multiple_args2multiple_cites, _CODE_BLOCK, _MATH_BLOCK, DEFAULT_ARGLIST
+from .common import default_movie, plain_exercise, table_analysis, indent_lines, \
+    bibliography, fix_ref_section_chapter, cite_with_multiple_args2multiple_cites, \
+    _CODE_BLOCK, _MATH_BLOCK, DEFAULT_ARGLIST
 from .doconce import INLINE_TAGS_SUBST, INLINE_TAGS
 from .latex import fix_latex_command_regex
 from .html import html_movie, html_table
 from .pandoc import pandoc_ref_and_label, pandoc_index_bib, pandoc_quote, \
      language2pandoc, pandoc_quiz
-from .misc import option, _abort, errwarn
+from .misc import option, errwarn, _abort
 from doconce import globals
-#from . import jupyter_execution
+from . import jupyter_execution
 
 try:
     from nbformat.v4 import new_code_cell, new_markdown_cell, new_notebook, new_output
@@ -95,6 +95,7 @@ def ipynb_author(authors_and_institutions, auth2index,
 
 def ipynb_table(table):
     text = html_table(table)
+    text += '\n'
     # Fix the problem that `verbatim` inside the table is not
     # typeset as verbatim (according to the ipynb translator rules)
     # in the GitHub Issue Tracker
